
# Slot: is current




URI: [ks:is_current](https://w3id.org/linkml/tests/kitchen_sink/is_current)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [BirthEvent](BirthEvent.md)
 * [EmploymentEvent](EmploymentEvent.md)
 * [Event](Event.md)
 * [MarriageEvent](MarriageEvent.md)
 * [MedicalEvent](MedicalEvent.md)
